@@ -1,5 +1,5 @@
 dctrl <-
-function(d,correct)
+function(d,correct,items)
 {
   problemlist <- list()  
   a <- 1  
@@ -14,13 +14,13 @@ function(d,correct)
   }
   
   # ~~~~~~~~~~~~~~~~~~~~~~~~ minimum
-  minimum <- sapply(d,function(x)min(as.numeric(x),na.rm=T) == 1)
-  if(!any(minimum))
-  {
-    problemlist[[a]] <- "minimum != 1 in at least one column!"
-    a <- a + 1
-    probl <- TRUE
-  }
+  minimum <- sapply(d,function(x)min(as.numeric(x),na.rm=T) == 0)
+#   if(!any(minimum))
+#   {
+#     problemlist[[a]] <- "minimum != 1 in at least one column!"
+#     a <- a + 1
+#     probl <- TRUE
+#   }
   
   # ~~~~~~~~~~~~~~~~~~~~~~~~ number of cat
   
@@ -51,5 +51,34 @@ function(d,correct)
     probl <- TRUE
   }
   
+  
+
   list(problemlist=problemlist,probl=probl)
 }
+
+
+
+################## more controls #######################
+
+
+dctrl2 <-
+  function(d_new,da,items)
+  {
+    
+    
+# checks the number of obs in each category!    
+    testdim <- lapply(d_new,function(x)
+      {
+        apply(x,2,function(aa3) sort(unique(aa3)))  
+      })
+    
+    if(!all(sapply(testdim[-1],function(td) identical(td,testdim[[1]])))){stop("At least in one item there are categories with no observations in one of the groups!")}
+    
+
+    ## all successive
+    if(!all(sapply(da[,items],function(zzq) all(diff(sort(unique(zzq)),lag=1)==1) ))){stop("Category levels must be consecutive numbers!")} # thx to CH for nice error message! see pcIRT :-)
+      
+
+
+  }
+
